Method: Guard::Copy#initialize
- Defined in:
- lib/guard/copy.rb
#initialize(options = {}) ⇒ Copy
Initializes a Guard plugin. Don’t do any work here, especially as Guard plugins get initialized even if they are not in an active group!
23 24 25 26 27 |
# File 'lib/guard/copy.rb', line 23 def initialize( = {}) inject_watchers() super @targets = Array([:to]).map { |to| Target.new(to, ) } end |